- datasets
character vector. Code of the datasets.
- model_name
character vector. Paleo climate model name see the
model_name column in the result.
- epoch
character vector. Epoch for which you want the paleo layer, e.g.
"mid-Holocene", "Last Glacial Maximum".
- years_ago
integer. Years for which you want the paleo layer, e.g.
6000, 21000.
- terrestrial
logical. When TRUE (default), then datasets that
only have terrestrial data (seamasked) are returned.
- marine
logical. When TRUE (default), then datasets that only
have marine data (landmasked) are returned.
- freshwater
logical. When TRUE, then datasets that only have
freshwater data are returned.
- monthly
logical. When FALSE, then no monthly layers are
returned. All annual and monthly layers are returned by default.
- version
numeric vector. When NULL then layers from all versions
of datasets are returned (default) else layers are filtered by version
number.